@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
- * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,17 +33,17 @@
 extern gchar *selected_connection;
 
 
-
+/* Clears the VPN client log */
 void clear_log_tab(struct w *widgets)
 {
-    /* Clears the VPN client log */
     FILE *fp;
-    gchar *log_path = g_strdup_printf("%s/client/%s/openvpn-client.log", OPENVPN_SYSCONF_DIR, selected_connection);
+    gchar *log_path = g_strdup_printf("%s/log/gadmin-openvpn/client/%s/openvpn-client.log",
+                                                         LOCALSTATEDIR, selected_connection);
 
     if((fp=fopen(log_path, "w+"))==NULL)
     {
-	g_free(log_path);
-	return;
+        g_free(log_path);
+        return;
     }
     fclose(fp);
     g_free(log_path);
