@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
- * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2012 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,12 +25,11 @@
 
 extern struct w *widgets;
 
-int cmplowercase(char *buf, char *cmpstring);
-
+int  cmplowercase(char *buf, char *cmpstring);
 char *encrypt_password(G_CONST_RETURN gchar *password);
-
 void make_dir_chmod(gchar *directory, char perm[128]);
-
 void chmod_file(gchar *filepath, char perm[128]);
+int  commented(char *line);
+int  chars_are_digits(char *buf);
 
 #endif
